pub struct CreateBoard;Trait Implementations
Sourceimpl GraphQLQuery for CreateBoard
impl GraphQLQuery for CreateBoard
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for CreateBoard
impl RefUnwindSafe for CreateBoard
impl Send for CreateBoard
impl Sync for CreateBoard
impl Unpin for CreateBoard
impl UnwindSafe for CreateBoard