pub struct EnableOtp;Trait Implementations
Sourceimpl GraphQLQuery for EnableOtp
impl GraphQLQuery for EnableOtp
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for EnableOtp
impl RefUnwindSafe for EnableOtp
impl Send for EnableOtp
impl Sync for EnableOtp
impl Unpin for EnableOtp
impl UnwindSafe for EnableOtp