pub struct Tasks;Trait Implementations
Sourceimpl GraphQLQuery for Tasks
impl GraphQLQuery for Tasks
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for Tasks
impl RefUnwindSafe for Tasks
impl Send for Tasks
impl Sync for Tasks
impl Unpin for Tasks
impl UnwindSafe for Tasks