pub struct UncompleteProject;Trait Implementations
Sourceimpl GraphQLQuery for UncompleteProject
impl GraphQLQuery for UncompleteProject
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for UncompleteProject
impl RefUnwindSafe for UncompleteProject
impl Send for UncompleteProject
impl Sync for UncompleteProject
impl Unpin for UncompleteProject
impl UnwindSafe for UncompleteProject