pub struct UpdateUserSettings;Trait Implementations
Sourceimpl GraphQLQuery for UpdateUserSettings
impl GraphQLQuery for UpdateUserSettings
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for UpdateUserSettings
impl RefUnwindSafe for UpdateUserSettings
impl Send for UpdateUserSettings
impl Sync for UpdateUserSettings
impl Unpin for UpdateUserSettings
impl UnwindSafe for UpdateUserSettings